@@ -1,6 +1,4 @@
-from typing import Dict
-
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict
 
 from pyodk._utils.session import Session
 
@@ -8,19 +6,16 @@ from pyodk._utils.session import Session
 class Model(BaseModel):
     """Base configuration for data model classes."""
 
-    class Config:
-        arbitrary_types_allowed = True
-        validate_assignment = True
+    model_config = ConfigDict(arbitrary_types_allowed=True, validate_assignment=True)
 
 
 class Manager:
     """Base for managers of data model classes."""
 
     __slots__ = ("__weakref__",)
-    pass
 
     @classmethod
-    def from_dict(cls, session: Session, project_id: int, data: Dict) -> Model:
+    def from_dict(cls, session: Session, project_id: int, data: dict) -> Model:
         raise NotImplementedError()
 
 
@@ -28,4 +23,3 @@ class Service:
     """Base for services interacting with the ODK Central API over HTTP."""
 
     __slots__ = ("__weakref__",)
-    pass
