@@ -1,6 +1,8 @@
-from typing import Callable, Optional
+from collections.abc import Callable
 
 from pyodk._endpoints.comments import CommentService
+from pyodk._endpoints.entities import EntityService
+from pyodk._endpoints.entity_lists import EntityListService
 from pyodk._endpoints.forms import FormService
 from pyodk._endpoints.projects import ProjectService
 from pyodk._endpoints.submissions import SubmissionService
@@ -28,14 +30,14 @@ class Client:
 
     def __init__(
         self,
-        config_path: Optional[str] = None,
-        cache_path: Optional[str] = None,
-        project_id: Optional[int] = None,
-        session: Optional[Session] = None,
-        api_version: Optional[str] = "v1",
+        config_path: str | None = None,
+        cache_path: str | None = None,
+        project_id: int | None = None,
+        session: Session | None = None,
+        api_version: str | None = "v1",
     ) -> None:
         self.config: config.Config = config.read_config(config_path=config_path)
-        self._project_id: Optional[int] = project_id
+        self._project_id: int | None = project_id
         if session is None:
             session = Session(
                 base_url=self.config.central.base_url,
@@ -67,9 +69,15 @@ class Client:
         self._comments: CommentService = CommentService(
             session=self.session, default_project_id=self.project_id
         )
+        self.entities: EntityService = EntityService(
+            session=self.session, default_project_id=self.project_id
+        )
+        self.entity_lists: EntityListService = EntityListService(
+            session=self.session, default_project_id=self.project_id
+        )
 
     @property
-    def project_id(self) -> Optional[int]:
+    def project_id(self) -> int | None:
         if self._project_id is None:
             return self.config.central.default_project_id
         else:
